==> ejc-zdsstore-api-3.0.0-20231224.063958-32-sources.jar: com/ejianc/business/zdsstore/vo/AllotInExportVO.java <==
package com.ejianc.business.zdsstore.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 调拨入库
 *
 * @author generator
 *
 */
public class AllotInExportVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 单据编码
    private Integer billState; // 单据状态
    private Long allotOutId; // 调拨入库id
    private Long projectId; // 出库项目id
    private String projectName; // 入库项目名称
    private Long orgId; // 入库组织id
    private String orgName; // 入库组织名称
    private Long parentOrgId; // 项目部上级组织Id
    private String parentOrgName; // 项目部上级组织名称
    private String parentOrgCode; // 项目部上级组织编码
    private Long storeId; // 入库仓库id
    private String storeName; // 入库仓库名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date outDate; // 调出的时间
    private BigDecimal outMny; // 调出金额
    private Integer allocatType; // 调拨方式 1 资产盘活 2 自制
    private Long employeeId; // 经办人id
    private String employeeName; // 经办人
    private Long departmentId; // 经办人部门id
    private String departmentName; //  经办人部门
    private Long outProjectId; // 调出项目id
    private String outProjectName; // 调出项目名称
    private Long outOrgId; // 调出组织id
    private String outOrgName; // 调出组织名称
    private String materialNames; // 出库物资名称集合
    private Long notifyReceiverId; // 通知收料状人id
    private String receiverName; // 调入组织收料状人
    private String receiverPersonId; // 收料人id
    private String receiverPerson; // 收料人
    private Date receiveDate; // 收料时间
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date passDate; // 通过时间
    private String returnReason; // 退回原因
    private Integer receiveState; // 收料状态 1、待收；2、已收；3、退回
    private String memo; // 备注
    private Long outStoreId; // 出库id
    private String outStoreName; // 出库名称
    private String billStateName;//单据状态名字
    private String receiveStateName;//收料状态名字
    private String allocatTypeName;//调拨方式 名字
    private String allocatDate;//调出日期
    private String allocatReceiveDate;//收料日期
    private String  allocatPassDate; //通过时间
    private List<AllotInDetailVO> allotInDetailList = new ArrayList<>(); // 调拨入库子表

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getAllotOutId() {
        return allotOutId;
    }

    public void setAllotOutId(Long allotOutId) {
        this.allotOutId = allotOutId;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    @ReferSerialTransfer(referCode="zdsstore-store")
    public Long getStoreId() {
        return storeId;
    }
    @ReferDeserialTransfer
    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }
    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public Date getOutDate() {
        return outDate;
    }

    public void setOutDate(Date outDate) {
        this.outDate = outDate;
    }

    public BigDecimal getOutMny() {
        return outMny;
    }

    public void setOutMny(BigDecimal outMny) {
        this.outMny = outMny;
    }

    public Integer getAllocatType() {
        return allocatType;
    }

    public void setAllocatType(Integer allocatType) {
        this.allocatType = allocatType;
    }

    @ReferSerialTransfer(referCode="idm-user")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getOutProjectId() {
        return outProjectId;
    }
    @ReferDeserialTransfer
    public void setOutProjectId(Long outProjectId) {
        this.outProjectId = outProjectId;
    }
    public String getOutProjectName() {
        return outProjectName;
    }

    public void setOutProjectName(String outProjectName) {
        this.outProjectName = outProjectName;
    }
    public Long getOutOrgId() {
        return outOrgId;
    }

    public void setOutOrgId(Long outOrgId) {
        this.outOrgId = outOrgId;
    }
    public String getOutOrgName() {
        return outOrgName;
    }

    public void setOutOrgName(String outOrgName) {
        this.outOrgName = outOrgName;
    }
    public String getMaterialNames() {
        return materialNames;
    }

    public void setMaterialNames(String materialNames) {
        this.materialNames = materialNames;
    }
    @ReferSerialTransfer(referCode="idm-user")
    public Long getNotifyReceiverId() {
        return notifyReceiverId;
    }
    @ReferDeserialTransfer
    public void setNotifyReceiverId(Long notifyReceiverId) {
        this.notifyReceiverId = notifyReceiverId;
    }

    public String getReceiverName() {
        return receiverName;
    }

    public void setReceiverName(String receiverName) {
        this.receiverName = receiverName;
    }

    public String getReceiverPersonId() {
        return receiverPersonId;
    }

    public void setReceiverPersonId(String receiverPersonId) {
        this.receiverPersonId = receiverPersonId;
    }

    public String getReceiverPerson() {
        return receiverPerson;
    }

    public void setReceiverPerson(String receiverPerson) {
        this.receiverPerson = receiverPerson;
    }

    public Date getReceiveDate() {
        return receiveDate;
    }

    public void setReceiveDate(Date receiveDate) {
        this.receiveDate = receiveDate;
    }

    public Date getPassDate() {
        return passDate;
    }

    public void setPassDate(Date passDate) {
        this.passDate = passDate;
    }

    public String getReturnReason() {
        return returnReason;
    }

    public void setReturnReason(String returnReason) {
        this.returnReason = returnReason;
    }

    public Integer getReceiveState() {
        return receiveState;
    }

    public void setReceiveState(Integer receiveState) {
        this.receiveState = receiveState;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    @ReferSerialTransfer(referCode="zdsstore-store")
    public Long getOutStoreId() {
        return outStoreId;
    }
    @ReferDeserialTransfer
    public void setOutStoreId(Long outStoreId) {
        this.outStoreId = outStoreId;
    }
    public String getOutStoreName() {
        return outStoreName;
    }

    public void setOutStoreName(String outStoreName) {
        this.outStoreName = outStoreName;
    }

     public List<AllotInDetailVO> getAllotInDetailList() {
        return allotInDetailList;
     }

     public void setAllotInDetailList(List<AllotInDetailVO> allotInDetailList) {
        this.allotInDetailList = allotInDetailList;
     }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getReceiveStateName() {
        return receiveStateName;
    }

    public void setReceiveStateName(String receiveStateName) {
        this.receiveStateName = receiveStateName;
    }

    public String getAllocatTypeName() {
        return allocatTypeName;
    }

    public void setAllocatTypeName(String allocatTypeName) {
        this.allocatTypeName = allocatTypeName;
    }

    public String getAllocatDate() {
        return allocatDate;
    }

    public void setAllocatDate(String allocatDate) {
        this.allocatDate = allocatDate;
    }

    public String getAllocatReceiveDate() {
        return allocatReceiveDate;
    }

    public void setAllocatReceiveDate(String allocatReceiveDate) {
        this.allocatReceiveDate = allocatReceiveDate;
    }

    public String getAllocatPassDate() {
        return allocatPassDate;
    }

    public void setAllocatPassDate(String allocatPassDate) {
        this.allocatPassDate = allocatPassDate;
    }
}

==> ejc-zdsstore-api-3.0.0-20240319.065455-189-sources.jar: com/ejianc/business/zdsstore/vo/AllotInExportVO.java <==
package com.ejianc.business.zdsstore.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 调拨入库
 *
 * @author generator
 *
 */
public class AllotInExportVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 单据编码
    private Integer billState; // 单据状态
    private Long allotOutId; // 调拨入库id
    private Long projectId; // 出库项目id
    private String projectName; // 入库项目名称
    private Long orgId; // 入库组织id
    private String orgName; // 入库组织名称
    private Long parentOrgId; // 项目部上级组织Id
    private String parentOrgName; // 项目部上级组织名称
    private String parentOrgCode; // 项目部上级组织编码
    private Long storeId; // 入库仓库id
    private String storeName; // 入库仓库名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date outDate; // 调出的时间
    private BigDecimal outMny; // 调出金额
    private Integer allocatType; // 调拨方式 1 资产盘活 2 自制
    private Long employeeId; // 经办人id
    private String employeeName; // 经办人
    private Long departmentId; // 经办人部门id
    private String departmentName; //  经办人部门
    private Long outProjectId; // 调出项目id
    private String outProjectName; // 调出项目名称
    private Long outOrgId; // 调出组织id
    private String outOrgName; // 调出组织名称
    private String materialNames; // 出库物资名称集合
    private Long notifyReceiverId; // 通知收料状人id
    private String receiverName; // 调入组织收料状人
    private String receiverPersonId; // 收料人id
    private String receiverPerson; // 收料人
    private Date receiveDate; // 收料时间
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date passDate; // 通过时间
    private String returnReason; // 退回原因
    private Integer receiveState; // 收料状态 1、待收；2、已收；3、退回
    private String memo; // 备注
    private Long outStoreId; // 出库id
    private String outStoreName; // 出库名称
    private String billStateName;//单据状态名字
    private String receiveStateName;//收料状态名字
    private String allocatTypeName;//调拨方式 名字
    private String allocatDate;//调出日期
    private String allocatReceiveDate;//收料日期
    private String  allocatPassDate; //通过时间
    private List<AllotInDetailVO> allotInDetailList = new ArrayList<>(); // 调拨入库子表
    private String orgCode; // 项目组织编码
    private String inCompanyName; // 调入单位名称(项目大区)
    private String companyName; // 调出单位名称（项目大区）
    private String outProjectCode; // 调出项目编码
    private String projectCode; // 出库项目编码
    private Integer allocatInType; // 调拨出库类型 1 项目仓库 2 大区仓库
    private Long inStoreOrgId;//调入单位
    private String inStoreOrgName;//调入单位 名称
    private String inStoreOrgCode;//调入单位 编码
    private Long outStoreOrgId;//调出单位
    private String outStoreOrgName;//调出单位 名称
    private String outStoreOrgCode;//调出单位 编码

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getInCompanyName() {
        return inCompanyName;
    }

    public void setInCompanyName(String inCompanyName) {
        this.inCompanyName = inCompanyName;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getOutProjectCode() {
        return outProjectCode;
    }

    public void setOutProjectCode(String outProjectCode) {
        this.outProjectCode = outProjectCode;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public Integer getAllocatInType() {
        return allocatInType;
    }

    public void setAllocatInType(Integer allocatInType) {
        this.allocatInType = allocatInType;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getInStoreOrgId() {
        return inStoreOrgId;
    }
    @ReferDeserialTransfer
    public void setInStoreOrgId(Long inStoreOrgId) {
        this.inStoreOrgId = inStoreOrgId;
    }

    public String getInStoreOrgName() {
        return inStoreOrgName;
    }

    public void setInStoreOrgName(String inStoreOrgName) {
        this.inStoreOrgName = inStoreOrgName;
    }

    public String getInStoreOrgCode() {
        return inStoreOrgCode;
    }

    public void setInStoreOrgCode(String inStoreOrgCode) {
        this.inStoreOrgCode = inStoreOrgCode;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOutStoreOrgId() {
        return outStoreOrgId;
    }
    @ReferDeserialTransfer
    public void setOutStoreOrgId(Long outStoreOrgId) {
        this.outStoreOrgId = outStoreOrgId;
    }

    public String getOutStoreOrgName() {
        return outStoreOrgName;
    }

    public void setOutStoreOrgName(String outStoreOrgName) {
        this.outStoreOrgName = outStoreOrgName;
    }

    public String getOutStoreOrgCode() {
        return outStoreOrgCode;
    }

    public void setOutStoreOrgCode(String outStoreOrgCode) {
        this.outStoreOrgCode = outStoreOrgCode;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getAllotOutId() {
        return allotOutId;
    }

    public void setAllotOutId(Long allotOutId) {
        this.allotOutId = allotOutId;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    @ReferSerialTransfer(referCode="zdsstore-store")
    public Long getStoreId() {
        return storeId;
    }
    @ReferDeserialTransfer
    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }
    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public Date getOutDate() {
        return outDate;
    }

    public void setOutDate(Date outDate) {
        this.outDate = outDate;
    }

    public BigDecimal getOutMny() {
        return outMny;
    }

    public void setOutMny(BigDecimal outMny) {
        this.outMny = outMny;
    }

    public Integer getAllocatType() {
        return allocatType;
    }

    public void setAllocatType(Integer allocatType) {
        this.allocatType = allocatType;
    }

    @ReferSerialTransfer(referCode="idm-user")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getOutProjectId() {
        return outProjectId;
    }
    @ReferDeserialTransfer
    public void setOutProjectId(Long outProjectId) {
        this.outProjectId = outProjectId;
    }
    public String getOutProjectName() {
        return outProjectName;
    }

    public void setOutProjectName(String outProjectName) {
        this.outProjectName = outProjectName;
    }
    public Long getOutOrgId() {
        return outOrgId;
    }

    public void setOutOrgId(Long outOrgId) {
        this.outOrgId = outOrgId;
    }
    public String getOutOrgName() {
        return outOrgName;
    }

    public void setOutOrgName(String outOrgName) {
        this.outOrgName = outOrgName;
    }
    public String getMaterialNames() {
        return materialNames;
    }

    public void setMaterialNames(String materialNames) {
        this.materialNames = materialNames;
    }
    @ReferSerialTransfer(referCode="idm-user")
    public Long getNotifyReceiverId() {
        return notifyReceiverId;
    }
    @ReferDeserialTransfer
    public void setNotifyReceiverId(Long notifyReceiverId) {
        this.notifyReceiverId = notifyReceiverId;
    }

    public String getReceiverName() {
        return receiverName;
    }

    public void setReceiverName(String receiverName) {
        this.receiverName = receiverName;
    }

    public String getReceiverPersonId() {
        return receiverPersonId;
    }

    public void setReceiverPersonId(String receiverPersonId) {
        this.receiverPersonId = receiverPersonId;
    }

    public String getReceiverPerson() {
        return receiverPerson;
    }

    public void setReceiverPerson(String receiverPerson) {
        this.receiverPerson = receiverPerson;
    }

    public Date getReceiveDate() {
        return receiveDate;
    }

    public void setReceiveDate(Date receiveDate) {
        this.receiveDate = receiveDate;
    }

    public Date getPassDate() {
        return passDate;
    }

    public void setPassDate(Date passDate) {
        this.passDate = passDate;
    }

    public String getReturnReason() {
        return returnReason;
    }

    public void setReturnReason(String returnReason) {
        this.returnReason = returnReason;
    }

    public Integer getReceiveState() {
        return receiveState;
    }

    public void setReceiveState(Integer receiveState) {
        this.receiveState = receiveState;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    @ReferSerialTransfer(referCode="zdsstore-store")
    public Long getOutStoreId() {
        return outStoreId;
    }
    @ReferDeserialTransfer
    public void setOutStoreId(Long outStoreId) {
        this.outStoreId = outStoreId;
    }
    public String getOutStoreName() {
        return outStoreName;
    }

    public void setOutStoreName(String outStoreName) {
        this.outStoreName = outStoreName;
    }

     public List<AllotInDetailVO> getAllotInDetailList() {
        return allotInDetailList;
     }

     public void setAllotInDetailList(List<AllotInDetailVO> allotInDetailList) {
        this.allotInDetailList = allotInDetailList;
     }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getReceiveStateName() {
        return receiveStateName;
    }

    public void setReceiveStateName(String receiveStateName) {
        this.receiveStateName = receiveStateName;
    }

    public String getAllocatTypeName() {
        return allocatTypeName;
    }

    public void setAllocatTypeName(String allocatTypeName) {
        this.allocatTypeName = allocatTypeName;
    }

    public String getAllocatDate() {
        return allocatDate;
    }

    public void setAllocatDate(String allocatDate) {
        this.allocatDate = allocatDate;
    }

    public String getAllocatReceiveDate() {
        return allocatReceiveDate;
    }

    public void setAllocatReceiveDate(String allocatReceiveDate) {
        this.allocatReceiveDate = allocatReceiveDate;
    }

    public String getAllocatPassDate() {
        return allocatPassDate;
    }

    public void setAllocatPassDate(String allocatPassDate) {
        this.allocatPassDate = allocatPassDate;
    }
}
